Contributors
============

* Aaron Egaas <me@aaronegaas.com>
* Aditya Bhasin <conlini@gmail.com>
* Alexis Métaireau <alexis@mozilla.com>
* Andy McKay <amckay@mozilla.com>
* Dan Phrawzty <phrawzty+github@gmail.com>
* David Larlet <david@larlet.fr>
* Eric Bréhault <ebrehault@gmail.com>
* Fil <fil@rezo.net>
* Greeshma <https://github.com/greeshmab>
* John Giannelos <johngiannelos@gmail.com>
* Mathieu Agopian <mathieu@agopian.info>
* Mathieu Leplatre <mathieu@mozilla.com>
* Nicolas Perriault <nperriault@mozilla.com>
* Nicolas Hoizey <nicolas@hoizey.com>
* Niraj <https://github.com/niraj8>
* Rektide <rektide@voodoowarez.com>
* Rémy Hubscher <rhubscher@mozilla.com>
* Shweta Oak <oakshweta11@gmail.com>
* Sofia Utsch <sofia.utsch@gmail.com>
* Tarek Ziade <tarek@mozilla.com>
* Wil Clouser <wclouser@mozilla.com>
